```
Usage: vcd network external update [OPTIONS] <name>

Options:
  -n, --name <name>               New name of the external network
  -d, --description <description>
                                  New description of the external network
  -h, --help                      Show this message and exit.

```
